@@ -12,7 +12,11 @@
 
         if ( exists( $args->{q[cards]} ) ) {
             (
-                do { package Type::Tiny; ref( $args->{q[cards]} ) eq 'ARRAY' }
+                do {
+
+                    package Acme::Mitey::Cards::Mite;
+                    ref( $args->{q[cards]} ) eq 'ARRAY';
+                  }
                   and do {
                     my $ok = 1;
                     for my $i ( @{ $args->{q[cards]} } ) {
@@ -58,7 +62,7 @@ q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::M
                     my $default_value = $_[0]->_build_cards;
                     do {
 
-                        package Type::Tiny;
+                        package Acme::Mitey::Cards::Mite;
                         ( ref($default_value) eq 'ARRAY' ) and do {
                             my $ok = 1;
                             for my $i ( @{$default_value} ) {
